@@ -210,6 +210,9 @@ int main(int argc, char **argv)
 
   } // End main loop
 
+  // Center joystick before quitting
+  do_uinput(uinput_fd, ABS_X, 0, EV_ABS);
+  do_uinput(uinput_fd, ABS_Y, 0, EV_ABS);
   printf("Accelemymote service shutting down. The program made %ik reads of the accelerometer with %i errors.\n",config.samples*frames/1000, read_errors);
   return 0;
 }
